FailedStrategy

Struct FailedStrategy 

pub struct FailedStrategy<'a, T, S: ?Sized, V> {
    pub strategy: &'a S,
    pub cause: V,
    /* private fields */
}
Error indicating that a strategy failed at a particular position.

Fields

strategy: &'a S

Strategy.

cause: V

Verification error.

Implementations

Source

impl<'a, T, S: Strategy, V> FailedStrategy<'a, T, S, V>

pub fn erased_strategy(self) -> FailedStrategy<'a, T, dyn StrategyObj + 'a, V>

Erase the strategy type, so the error can be more general.

Source

impl<'a, T, S: ?Sized, V> FailedStrategy<'a, T, S, V>

pub fn empty(strategy: &'a S, cause: V) -> FailedStrategy<'a, T, S, V>

Creates an error for an empty result.

pub fn map<U, F: FnOnce(V) -> U>(self, f: F) -> FailedStrategy<'a, T, S, U>

Applies a function to the cause.

pub fn index(&self) -> Option<usize>

Get the unsigned index of the error.

pub fn valid_forward(&self) -> RangeTo<usize>

Get the valid values in the forward direction.

pub fn valid_backward(&self) -> RangeFrom<usize>

Get the valid values in the backward direction.