pub struct FailedStrategy<'a, T, S: ?Sized, V> {
pub strategy: &'a S,
pub cause: V,
/* private fields */
}Expand description
Error indicating that a strategy failed at a particular position.
Fields
strategy: &'a SStrategy.
cause: VVerification error.
Implementations
Sourceimpl<'a, T, S: Strategy, V> FailedStrategy<'a, T, S, V>
impl<'a, T, S: Strategy, V> FailedStrategy<'a, T, S, V>
Sourcepub fn erased_strategy(self) -> FailedStrategy<'a, T, dyn StrategyObj + 'a, V>
pub fn erased_strategy(self) -> FailedStrategy<'a, T, dyn StrategyObj + 'a, V>
Erase the strategy type, so the error can be more general.
Sourceimpl<'a, T, S: ?Sized, V> FailedStrategy<'a, T, S, V>
impl<'a, T, S: ?Sized, V> FailedStrategy<'a, T, S, V>
Sourcepub fn empty(strategy: &'a S, cause: V) -> FailedStrategy<'a, T, S, V>
pub fn empty(strategy: &'a S, cause: V) -> FailedStrategy<'a, T, S, V>
Creates an error for an empty result.
Sourcepub fn map<U, F: FnOnce(V) -> U>(self, f: F) -> FailedStrategy<'a, T, S, U>
pub fn map<U, F: FnOnce(V) -> U>(self, f: F) -> FailedStrategy<'a, T, S, U>
Applies a function to the cause.
Sourcepub fn valid_forward(&self) -> RangeTo<usize>
pub fn valid_forward(&self) -> RangeTo<usize>
Get the valid values in the forward direction.
Sourcepub fn valid_backward(&self) -> RangeFrom<usize>
pub fn valid_backward(&self) -> RangeFrom<usize>
Get the valid values in the backward direction.